<?php

namespace Drupal\currencyapi;

use Drupal\Core\State\StateInterface;

/**
 * Provides currency exchange rates from CurrencyAPI.com.
 */

class CurrencyApiCron {

  /**
   * Constructs a new FileExampleHelper object.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The state.
   */
  public function __construct(protected StateInterface $state) {
    $this->state = $state;
  }

  /**
   * Cron the task.
   */
  public function cron() {

    $now = \Drupal::time()->getRequestTime();
    if ($this->shouldRun($now)) {
      $this->queueTasks();
      $this->state->set('currencyapi.last_cron', $now);
    }
  }

  /**
   * Check is to be run.
   */
  public function shouldRun($now) {

    $d = [];

    // Get these from config or something:
    $d['now'] = $now;
    $d['scheduled'] = '07:30';
    $d['timezone'] = new \DateTimeZone('Europe/Rome');
    $d['timestamp_last'] = $this->state->get('currencyapi.last_cron') ?? 0;

    $d['last'] = \DateTime::createFromFormat('U', $d['timestamp_last'])
      ->setTimezone($d['timezone']);
    $d['next'] = clone $d['last'];
    $d['next']->setTime(...explode(':', $d['scheduled']));

    if ($d['next']->getTimestamp() <= $d['last']->getTimestamp()) {
      $d['next']->modify('+1 day');
    }

    $d['output'] = $d['next']->getTimestamp() <= $d['now'];

    return $d['output'];
  }

  /**
   * Queue manager.
   */
  public function queueTasks() {
    $d = [];
    $d['service'] = \Drupal::service('currencyapi.service');
    $d['fetch_rates'] = $data['service']->fetchExchangeRates();

  }

}
